import re

ENV_LOAD_STATUS_KEY = 'ENV_CONFIG_LOADED'

DOT_ENV_FILE = ".env"

LOCAL_CONFIG_FILE_PREFIX = "local"

ENVIRONMENT_VARIABLE_NAME = "ENVIRONMENT"

DEBUG_VARIABLE_NAME = "ENVIRONMENT"

DEBUG_VARIABLE_VALUE = False
