
DEFAULT_DATE = "%Y-%m-%d"
DEFAULT_TIME = "%H:%M:%S"
TIMESTAMP = f"{DEFAULT_DATE} {DEFAULT_TIME}"

DEFAULT_DATE_SLASHED = '%Y/%m/%d'
TIMESTAMP_SLASHED = f"{DEFAULT_DATE_SLASHED} {DEFAULT_TIME}"
HUMAN_FORMAT = "%a %d %b %y, %I:%M:%S %p"
DEFAULT_TIMEZONE = 'Asia/Kolkata'